==> kipi-plugins-trinity-3.5.13.2.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/batchprocessimages/borderimagesdialog.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2004-10-01
 * Description : a kipi plugin to batch process images
 *
 * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef BORDERIMAGESDIALOG_H
#define BORDERIMAGESDIALOG_H

// Local includes

#include "batchprocessimagesdialog.h"
#include "kpaboutdata.h"

namespace KIPIBatchProcessImagesPlugin
{

class BatchProcessImagesItem;

class BorderImagesDialog : public BatchProcessImagesDialog
{
Q_OBJECT
  TQ_OBJECT

 public:
 
   BorderImagesDialog( KURL::List images, KIPI::Interface* interface, TQWidget *parent=0 );
   ~BorderImagesDialog();

 private slots:
 
   void slotHelp(void);
   void slotOptionsClicked(void);

 protected:
 
   int                    m_solidWidth;
   TQColor                 m_solidColor;

   int                    m_lineNiepceWidth;
   TQColor                 m_lineNiepceColor;
   int                    m_NiepceWidth;
   TQColor                 m_NiepceColor;

   int                    m_raiseWidth;

   int                    m_frameWidth;
   int                    m_bevelWidth;
   TQColor                 m_frameColor;

   TQString makeProcess(KProcess* proc, BatchProcessImagesItem *item,
                       const TQString& albumDest, bool previewMode);

   void readSettings(void);
   void saveSettings(void);

  private:

   KIPIPlugins::KPAboutData *m_about;
};

}  // NameSpace KIPIBatchProcessImagesPlugin

#endif  // BORDERIMAGESDIALOG_H

==> kipi-plugins-trinity_14.0.13.orig.tar.xz: kipi-plugins-trinity-14.0.13/kipi-plugins/batchprocessimages/borderimagesdialog.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2004-10-01
 * Description : a kipi plugin to batch process images
 *
 * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef BORDERIMAGESDIALOG_H
#define BORDERIMAGESDIALOG_H

// Local includes

#include "batchprocessimagesdialog.h"
#include "kpaboutdata.h"

namespace KIPIBatchProcessImagesPlugin
{

class BatchProcessImagesItem;

class BorderImagesDialog : public BatchProcessImagesDialog
{
Q_OBJECT
  

 public:
 
   BorderImagesDialog( KURL::List images, KIPI::Interface* interface, TQWidget *parent=0 );
   ~BorderImagesDialog();

 private slots:
 
   void slotHelp(void);
   void slotOptionsClicked(void);

 protected:
 
   int                    m_solidWidth;
   TQColor                 m_solidColor;

   int                    m_lineNiepceWidth;
   TQColor                 m_lineNiepceColor;
   int                    m_NiepceWidth;
   TQColor                 m_NiepceColor;

   int                    m_raiseWidth;

   int                    m_frameWidth;
   int                    m_bevelWidth;
   TQColor                 m_frameColor;

   TQString makeProcess(TDEProcess* proc, BatchProcessImagesItem *item,
                       const TQString& albumDest, bool previewMode);

   void readSettings(void);
   void saveSettings(void);

  private:

   KIPIPlugins::KPAboutData *m_about;
};

}  // NameSpace KIPIBatchProcessImagesPlugin

#endif  // BORDERIMAGESDIALOG_H
